legalsolarTermsHolidayDic={'清明':'清明节'}
legalHolidaysDic = {(1,1):'元旦节',(5,1):'国际劳动节',(10,1):'国庆节'}
legalLunarHolidaysDic = {(1,1):'春节',(5,5):'端午节',(8,15):'中秋节'}

otherHolidaysList = [
    {8: '周恩来逝世纪念日', 10: '中国公安110宣传日', 21: '列宁逝世纪念日', 26: '国际海关日'}, #1月
    {2: '世界湿地日', 4: '世界抗癌日', 7: '京汉铁路罢工纪念', 10: '国际气象节', 14: '情人节', 19: '邓小平逝世纪念日', 21: '国际母语日', 24: '第三世界青年日'},
    {1: '国际海豹日', 3: '全国爱耳日', 5: '周恩来诞辰纪念日,中国青年志愿者服务日', 6: '世界青光眼日', 8: '国际劳动妇女节', 12: '孙中山逝世纪念日,中国植树节', 14: '马克思逝世纪念日', 15: '国际消费者权益日', 17: '国际航海日', 18: '全国科技人才活动日', 21: '世界森林日,世界睡眠日', 22: '世界水日', 23: '世界气象日', 24: '世界防治结核病日'},
    {1: '国际愚人节', 2: '国际儿童图书日', 7: '世界卫生日', 22: '列宁诞辰纪念日', 23: '世界图书和版权日', 26: '世界知识产权日'},
    {3: '世界新闻自由日', 4: '中国青年节', 5: '马克思诞辰纪念日', 8: '世界红十字日', 11: '世界肥胖日', 23: '世界读书日', 27: '上海解放日', 31: '世界无烟日'},
    {1: '国际儿童节', 5: '世界环境日', 6: '全国爱眼日', 8: '世界海洋日', 11: '中国人口日', 14: '世界献血日'},
    {1: '中国共产党诞生日,香港回归纪念日', 7: '中国人民抗日战争纪念日', 11: '世界人口日'},
    {1: '中国人民解放军建军节', 5: '恩格斯逝世纪念日', 6: '国际电影节', 12: '国际青年日', 22: '邓小平诞辰纪念日'},
    {3: '中国抗日战争胜利纪念日', 8: '世界扫盲日', 9: '毛泽东逝世纪念日', 10: '中国教师节', 14: '世界清洁地球日', 18: '“九·一八”事变纪念日', 20: '全国爱牙日', 21: '国际和平日', 27: '世界旅游日'},
    {4: '世界动物日', 10: '辛亥革命纪念日', 13: '中国少年先锋队诞辰日', 25: '抗美援朝纪念日'},
    {12: '孙中山诞辰纪念日', 28: '恩格斯诞辰纪念日'},
    {1: '世界艾滋病日', 12: '西安事变纪念日', 13: '南京大屠杀纪念日', 24: '平安夜', 25: '圣诞节', 26: '毛泽东诞辰纪念日'} #12月
]

#复活节:每年春分后月圆第一个星期天  母亲节:每年5月份的第2个星期日  父亲节:每年6月份的第3个星期天感恩节 每年11月最后一个星期四
# otherEastHolidaysList={5:(2,7,'母亲节'),6:(3,7,'父亲节')}
otherLunarHolidaysList=[
    {1: '弥勒佛圣诞', 8: '五殿阎罗天子诞', 9: '玉皇上帝诞', 15: '元宵节'},
    {1: '一殿秦广王诞', 2: '春龙节-福德土地正神诞', 3: '文昌帝君诞', 6: '东华帝君诞', 8: '释迦牟尼佛出家', 15: '释迦牟尼佛般涅槃', 17: '东方杜将军诞', 18: '至圣先师孔子讳辰', 19: '观音大士诞', 21: '普贤菩萨诞'},
    {1: '二殿楚江王诞', 3: '三月三-玄天上帝诞', 8: '六殿卞城王诞', 15: '昊天上帝诞', 16: '准提菩萨诞', 19: '中岳大帝诞', 20: '子孙娘娘诞', 27: '七殿泰山王诞', 28: '苍颉至圣先师诞'},
    {1: '八殿都市王诞', 4: '文殊菩萨诞', 8: '释迦牟尼佛诞', 14: '纯阳祖师诞', 15: '钟离祖师诞', 17: '十殿转轮王诞', 18: '紫徽大帝诞', 20: '眼光圣母诞'},
    {1: '南极长生大帝诞', 8: '南方五道诞', 11: '天下都城隍诞', 12: '炳灵公诞', 13: '关圣降', 16: '天地元气造化万物之辰', 18: '张天师诞', 22: '孝娥神诞'},
    {19: '观世音菩萨成道日', 24: '关帝诞'},
    {7: '七夕-魁星诞', 13: '长真谭真人诞-大势至菩萨诞', 15: '中元节', 18: '西王母诞', 19: '太岁诞', 22: '增福财神诞', 29: '杨公忌', 30: '地藏菩萨诞'},
    {1: '许真君诞', 3: '司命灶君诞', 5: '雷声大帝诞', 10: '北斗大帝诞', 12: '西方五道诞', 16: '天曹掠刷真君降', 18: '天人兴福之辰', 23: '汉恒候张显王诞', 24: '灶君夫人诞', 29: '至圣先师孔子诞'},
    {1: '北斗九星降世', 3: '五瘟神诞', 9: '重阳节-酆都大帝诞', 13: '孟婆尊神诞', 17: '金龙四大王诞', 19: '观世音菩萨出家', 30: '药师琉璃光佛诞'},
    {1: '寒衣节', 3: '三茅诞', 5: '达摩祖师诞', 8: '佛涅槃日', 15: '下元节'},
    {4: '至圣先师孔子诞', 6: '西岳大帝诞', 11: '太乙救苦天尊诞', 17: '阿弥陀佛诞', 19: '太阳日宫诞', 23: '张仙诞', 26: '北方五道诞'},
    {8: '腊八节-释迦如来成佛之辰', 16: '南岳大帝诞', 21: '天猷上帝诞', 23: '小年', 24: '子时灶君上天朝玉帝', 29: '华严菩萨诞', 30: '除夕'}
]



import datetime, cnlunar
# print('a = cnlunar.Lunar(datetime.datetime(2021, 2, 7, 10, 30), godType=\'8char\')')
print('\n八字月柱与八字日柱算神煞版本')

# 常规算法 demo 应输出 壬寅
a = cnlunar.Lunar(datetime.datetime(2022, 1, 8, 1, 30), godType='8char')
# 八字立春切换算法 1986, 11, 1, 7, 0   demo 应输出  丙寅
# a = cnlunar.Lunar(datetime.datetime(1986, 11, 1, 7, 0), godType='8char')
# a = cnlunar.Lunar(datetime.datetime(1986, 11, 1, 7, 0), godType='8char', year8Char='beginningOfSpring')
# 八字立春切换算法  demo 应输出 辛丑
# a = cnlunar.Lunar(datetime.datetime(2022, 2, 3, 10, 30), godType='8char', year8Char='beginningOfSpring')
# 常规算法 (2024, 2, 4, 10, 30) demo 应输出 癸卯
# a = cnlunar.Lunar(datetime.datetime(2024, 2, 4, 10, 30), godType='8char')
# 八字立春切换算法  (2024, 2, 4, 10, 30) demo 应输出 甲辰
# a = cnlunar.Lunar(datetime.datetime(2024, 2, 4, 10, 30), godType='8char', year8Char='beginningOfSpring')  # 八字立春切换算法
dic = {
    '日期': a.date,
    '农历数字': (a.lunarYear, a.lunarMonth, a.lunarDay, '闰' if a.isLunarLeapMonth else ''),
    '农历': '%s %s[%s]年 %s%s' % (a.lunarYearCn, a.year8Char, a.chineseYearZodiac, a.lunarMonthCn, a.lunarDayCn),
    '星期': a.weekDayCn,
    # 未增加除夕
    '今日节日': (a.get_legalHolidays(), a.get_otherHolidays(), a.get_otherLunarHolidays()),
    '八字': ' '.join([a.year8Char, a.month8Char, a.day8Char, a.twohour8Char]),
    '今日节气': a.todaySolarTerms,
    '下一节气': (a.nextSolarTerm, a.nextSolarTermDate, a.nextSolarTermYear),
    '今年节气表': a.thisYearSolarTermsDic,
    '季节': a.lunarSeason,

    '今日时辰': a.twohour8CharList,
    '时辰凶吉': a.get_twohourLuckyList(),
    '生肖冲煞': a.chineseZodiacClash,
    '星座': a.starZodiac,
    '星次': a.todayEastZodiac,

    '彭祖百忌': a.get_pengTaboo(),
    '彭祖百忌精简': a.get_pengTaboo(long=4, delimit='<br>'),
    '十二神': a.get_today12DayOfficer(),
    '廿八宿': a.get_the28Stars(),

    '今日三合': a.zodiacMark3List,
    '今日六合': a.zodiacMark6,
    '今日五行': a.get_today5Elements(),

    '纳音': a.get_nayin(),
    '九宫飞星': a.get_the9FlyStar(),
    '吉神方位': a.get_luckyGodsDirection(),
    '今日胎神': a.get_fetalGod(),
    '神煞宜忌': a.angelDemon,
    '今日吉神': a.goodGodName,
    '今日凶煞': a.badGodName,
    '宜忌等第': a.todayLevelName,
    '宜': a.goodThing,
    '忌': a.badThing,
    '时辰经络': a.meridians
}
for i in dic:
    midstr = '\t' * (2 - len(i) // 2) + ':' + '\t'
    print(i, midstr, dic[i])


# --------------issues test--------------
# i=1
# c=0
# now = datetime.datetime(2022, 2, 4, 12, 30)
# while i <= 500:
#
#     a = cnlunar.Lunar(now,godType='cnlunar')
#     now += datetime.timedelta(days=1)
#     i += 1
#     # print(now)
#     n = cnlunar.Lunar(now, godType='8char')
#     print(n.angelDemon)
#     if '取鱼' in n.goodThing:
#         print('是1', n.today12DayOfficer)

# print('\n农历月份与八字日柱算神煞版本，月神随月建顺行者，算出来2019年2月4日是危日，虽然与书中卷九相符，但与市面上其他日历不符，不推荐此算法，推荐用默认月柱日柱算法')
# getLunar(datetime.datetime(2019, 2, 4, 22, 30), godType='cnlunar')

# import json
# class DateEncoder(json.JSONEncoder):
#     def default(self, obj):
#         if isinstance(obj,datetime.datetime):
#             return obj.strftime("%Y-%m-%d %H:%M:%S")
#         else:
#             return json.JSONEncoder.default(self,obj)
# dic = getLunar(datetime.datetime(2020,11,1,22,30))
# outptJson = json.dumps(dic, cls=DateEncoder)



# 工具拓展模块
# author: cuba3
# github: https://github.com/OPN48/pyLunarCalendar

# 去除空行
from cnlunar.config import ENC_VECTOR_LIST, thingsSort

def rfRemove(l=[],removeList=[]):
    for removeThing in list(set(l).intersection(set(removeList))):
        l.remove(removeThing)
    return l
def rfAdd(l=[],addList=[]):
    return list(set(l+addList))

def not_empty(s):
    return s and s.strip()

# 两个List合并对应元素相加或者相减，a[i]+b[i]:tpye=1 a[i]-b[i]:tpye=-1
def abListMerge(a, b=ENC_VECTOR_LIST, type=1):
    c = []
    for i in range(len(a)):
        c.append(a[i]+b[i]*type)
    return c

def sortCollation(x, sortList=thingsSort):
    if x in sortList:
        return sortList.index(x)
    else:
        return len(sortList) + 1


from setuptools import setup
setup(
    name='cnlunar',
    version='0.1.6',
    packages=['cnlunar'],
    url='https://github.com/OPN48/cnLunar',
    author='cuba3',
    author_email='cuba3@163.com',
    long_description=open('README.rst', encoding='utf-8').read(),
)
